# Galah-Interact (Python Library)

## What is Galah-Interact

Galah-Interact is a library designed to make it very easy to create Test
Harnesses that grade student's assignments. It provides code to perform a
number of tests that many instructors care about (such as checking that code is
properly indented, or that proper docstrings are created for each function)
along with providing utilities to make more complicated testing much easier
(unit testing for example is extremely easy with this library, as you can simply
import all of the student's functions and classes into Python).

The reason for Galah-Interact's creation was to make it easier to create Test
Harnesses for [Galah](http://www.github.com/galah-group/galah), however, we
don't have any intention on locking in this library's use. The real goal of
Galah-Interact is to provide a powerful framework for creating excellent
Test Harnesses no matter what the submission system you are using for your
class is.

## Examples

Adding tutorials and documentation has not been done yet, but there are
examples available under `docs/examples/` that is a great place to start.

## Licensing

The code is licensed under the Apache 2.0 license, which is a very permissive
license. You can read a summary of its specific terms on the wikipedia page
for the license
[here](http://en.wikipedia.org/wiki/Apache_License#Licensing_conditions). The
entire license text is also contained within this repository if you'd like to
read the license itself.

In short, the license is very permissive and lets you do basically whatever you
want with the code as long as you properly attribute the contributers. So as
long as you don't rip out the code and say you wrote it, your probably staying
within the terms of the license.

Note that this license is *very* different than the license that covers
[Galah](http://www.github.com/galah-group/galah) itself. Please don't confuse
the two.
